# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`mofed`](#mofed): Manage Mellanox OFED
* [`mofed::opensm`](#mofedopensm): Manage OpenSM
* [`mofed::srp`](#mofedsrp): Manage SRP

#### Private Classes

* `mofed::config`
* `mofed::install`
* `mofed::repo`
* `mofed::service`

### Defined types

* [`mofed::interface`](#mofedinterface): Manage IPoIB interface

## Classes

### <a name="mofed"></a>`mofed`

Manage Mellanox OFED

#### Examples

##### Basic usage using local yum repo for MOFED

```puppet
class { 'mofed':
  repo_baseurl => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/'
  repo_gpgkey  => 'http://example.com/mlnx/$releasever/3.4-2.0.0.0-rhel7.3/RPM-GPG-KEY-Mellanox',
}
```

#### Parameters

The following parameters are available in the `mofed` class:

* [`manage_repo`](#manage_repo)
* [`repo_baseurl`](#repo_baseurl)
* [`repo_gpgcheck`](#repo_gpgcheck)
* [`repo_gpgkey`](#repo_gpgkey)
* [`repo_exclude`](#repo_exclude)
* [`repo_priority`](#repo_priority)
* [`manage_packages`](#manage_packages)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`extra_packages`](#extra_packages)
* [`extra_packages_hiera_merge`](#extra_packages_hiera_merge)
* [`manage_service`](#manage_service)
* [`restart_service`](#restart_service)
* [`openibd_service_name`](#openibd_service_name)
* [`openibd_service_ensure`](#openibd_service_ensure)
* [`openibd_service_enable`](#openibd_service_enable)
* [`openibd_service_hasstatus`](#openibd_service_hasstatus)
* [`openibd_service_hasrestart`](#openibd_service_hasrestart)
* [`manage_config`](#manage_config)
* [`openib_config_path`](#openib_config_path)
* [`openib_shellvars`](#openib_shellvars)
* [`interfaces`](#interfaces)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Boolean to set if MOFED repo should be managed

Default value: ``true``

##### <a name="repo_baseurl"></a>`repo_baseurl`

Data type: `Optional[String]`

The baseurl of the yumrepo resource

Default value: ``undef``

##### <a name="repo_gpgcheck"></a>`repo_gpgcheck`

Data type: `Enum['1','0']`

The gpgcheck of the yumrepo resource

Default value: `'1'`

##### <a name="repo_gpgkey"></a>`repo_gpgkey`

Data type: `Optional[String]`

The gpgkey of the yumrepo resource

Default value: ``undef``

##### <a name="repo_exclude"></a>`repo_exclude`

Data type: `Optional[String]`

The exclude of the yumrepo resource

Default value: ``undef``

##### <a name="repo_priority"></a>`repo_priority`

Data type: `Optional[String]`

The priority of the yumrepo resource

Default value: ``undef``

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Boolean to determine if packages should be managed

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

The package ensure property

Default value: `'present'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

The MOFED package name to install

Default value: `'mlnx-ofed-basic'`

##### <a name="extra_packages"></a>`extra_packages`

Data type: `Optional[Array]`

An array of additional packages to install

Default value: ``undef``

##### <a name="extra_packages_hiera_merge"></a>`extra_packages_hiera_merge`

Data type: `Boolean`

Boolean that sets if extra_packages should have values merged from hiera

Default value: ``false``

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Boolean that determines if the openibd service should be managed

Default value: ``true``

##### <a name="restart_service"></a>`restart_service`

Data type: `Boolean`

Boolean that sets of openibd should be restarted

Default value: ``false``

##### <a name="openibd_service_name"></a>`openibd_service_name`

Data type: `String`

Name of the openibd service

Default value: `'openibd'`

##### <a name="openibd_service_ensure"></a>`openibd_service_ensure`

Data type: `String`

openibd service ensure property

Default value: `'running'`

##### <a name="openibd_service_enable"></a>`openibd_service_enable`

Data type: `Boolean`

openibd service enable property

Default value: ``true``

##### <a name="openibd_service_hasstatus"></a>`openibd_service_hasstatus`

Data type: `Boolean`

openibd service hasstatus property

Default value: ``true``

##### <a name="openibd_service_hasrestart"></a>`openibd_service_hasrestart`

Data type: `Boolean`

openibd service hasrestart property

Default value: ``true``

##### <a name="manage_config"></a>`manage_config`

Data type: `Boolean`

Boolean that sets if configs should be managed

Default value: ``true``

##### <a name="openib_config_path"></a>`openib_config_path`

Data type: `Stdlib::Absolutepath`

Path to openib.conf

Default value: `'/etc/infiniband/openib.conf'`

##### <a name="openib_shellvars"></a>`openib_shellvars`

Data type: `Hash`

Hash of shellvar resources

Default value: `{}`

##### <a name="interfaces"></a>`interfaces`

Data type: `Hash`

Hash of mofed::interface resources

Default value: `{}`

### <a name="mofedopensm"></a>`mofed::opensm`

Manage OpenSM

#### Examples

##### Manage OpenSM on two specific ports

```puppet
class { 'mofed::opensm':
  ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::opensm` class:

* [`ensure`](#ensure)
* [`ports`](#ports)
* [`sweep`](#sweep)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of opensm.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: `'present'`

##### <a name="ports"></a>`ports`

Data type: `Array`

Ports used by opensm

Default value: `[]`

##### <a name="sweep"></a>`sweep`

Data type: `Integer`

Value passsed to opensm `-s` argument.

Default value: `10`

### <a name="mofedsrp"></a>`mofed::srp`

Manage SRP

#### Examples

##### Manage SRP for specific ports

```puppet
class { 'mofed::srp':
 ports => ['mlx4_1 1', 'mlx4_1 2'],
}
```

#### Parameters

The following parameters are available in the `mofed::srp` class:

* [`ensure`](#ensure)
* [`ports`](#ports)
* [`srp_daemon_config`](#srp_daemon_config)
* [`ib_srp_options`](#ib_srp_options)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of srp.  `present` will run opensm.
`disabled` will install and configure opensm but disable services.
`absent` will remove opensm.

Default value: `'present'`

##### <a name="ports"></a>`ports`

Data type: `Array`

Ports used by srp daemon.

Default value: `[]`

##### <a name="srp_daemon_config"></a>`srp_daemon_config`

Data type: `Optional[Variant[String, Array]]`

Define lines in srp_daemon.conf

Default value: ``undef``

##### <a name="ib_srp_options"></a>`ib_srp_options`

Data type: `Optional[Hash[String, Variant[String,Integer], 1]]`

Options passed to ib_srp kernel module

Default value: ``undef``

## Defined types

### <a name="mofedinterface"></a>`mofed::interface`

Manage IPoIB interface

#### Examples

##### Add IPoIB interface

```puppet
mofed::interface { 'ib0':
  ensure         => 'present',
  ipaddr         => '10.0.0.1',
  netmask        => '255.255.0.0',
  connected_mode => 'no',
}
```

#### Parameters

The following parameters are available in the `mofed::interface` defined type:

* [`ipaddr`](#ipaddr)
* [`netmask`](#netmask)
* [`gateway`](#gateway)
* [`ensure`](#ensure)
* [`enable`](#enable)
* [`connected_mode`](#connected_mode)
* [`mtu`](#mtu)
* [`bonding`](#bonding)
* [`bonding_slaves`](#bonding_slaves)
* [`bonding_opts`](#bonding_opts)

##### <a name="ipaddr"></a>`ipaddr`

Data type: `Optional[Stdlib::Compat::Ip_address]`

IP address, required when ensure=present

Default value: ``undef``

##### <a name="netmask"></a>`netmask`

Data type: `Optional[Stdlib::Compat::Ip_address]`

Netmask address, required when ensure=present

Default value: ``undef``

##### <a name="gateway"></a>`gateway`

Data type: `Optional[Stdlib::Compat::Ip_address]`

Gateway address.

Default value: ``undef``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Interface ensure value.

Default value: `'present'`

##### <a name="enable"></a>`enable`

Data type: `Boolean`

Boolean of whether to enable the interface at boot.

Default value: ``true``

##### <a name="connected_mode"></a>`connected_mode`

Data type: `Enum['yes', 'no']`

The value for setting interface to connected mode.

Default value: `'yes'`

##### <a name="mtu"></a>`mtu`

Data type: `Optional[Integer]`

The MTU of the interface.

Default value: ``undef``

##### <a name="bonding"></a>`bonding`

Data type: `Boolean`

If this interface is a bonding interface

Default value: ``false``

##### <a name="bonding_slaves"></a>`bonding_slaves`

Data type: `Array[String]`

Array of interfaces that should be enslaved in the bonding interface

Default value: `[]`

##### <a name="bonding_opts"></a>`bonding_opts`

Data type: `String`

The bonding options to use for this bonding interface

Default value: `'mode=active-backup miimon=100'`

